@@ -49,7 +49,7 @@ add_widget_event();
 // GET Edit mode
 if ($("#editmode").length){
     $.ajax({
-        url: '/editmode',
+        url: 'editmode',
         type: "GET",
         dataType: "json",
     }).done(function(value){
@@ -62,7 +62,7 @@ if ($("#editmode").length){
 // Change Edit Mode
 $("#editmode").click(function(){
     $.post(
-        "/editmode",
+        "editmode",
         {editmode: $(this).hasClass('active')}
     ).done(function(value){
         if(value['editmode'] == true){
@@ -97,7 +97,7 @@ function add_widget(){
 function add_link(){
     new_link = new_links[0];
     $.post(
-        "/add",
+        "add",
         {
             link: new_link['url'],
             title: new_link['title'],
@@ -119,7 +119,7 @@ function del(button, link){
     table_tr = $(button).parents().eq(1);
     result_index = parseInt(table_tr[0].id.slice(8));
     $.post(
-        "/delete",
+        "delete",
         {link: link}
     ).done(function(value){
         initial_links.splice(result_index, 1);
@@ -136,7 +136,7 @@ function update(button, link){
     result_index = parseInt(table_tr[0].id.slice(8));
     new_link = new_links[result_index];
     $.post(
-        "/update",
+        "update",
         {
             link: link,
             title: new_link['title'],
@@ -619,7 +619,7 @@ $.fn.LMSuggest = function(opts){
 
     opts.source = function(request, response){
         $.ajax({
-            url: '/suggest',
+            url: 'suggest',
             dataType: 'json',
             data: {
                 tags: request.term,
@@ -650,7 +650,7 @@ $("#searchbar").click(function() {
 
 function suggest_callback(filter) {
     $.ajax({
-        url: '/suggest',
+        url: 'suggest',
         dataType: 'json',
         async: false,
         data: {
